==> 1.0.0-dev.2.tar.gz: test/agent/agent_impl_test.dart <==
import 'package:flutter/rendering.dart';
import 'package:flutter/services.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:tingyun_flutter_plugin/src/agent/agent_impl.dart';
import 'package:tingyun_flutter_plugin/src/agent/util/logger.dart';
import 'package:tingyun_flutter_plugin/tingyun_flutter_plugin.dart';

import '../dart_language_test.dart';

void main(){

  const MethodChannel methodChannel = MethodChannel(TingyunFlutterImpl.methodChannelName);
  TestWidgetsFlutterBinding.ensureInitialized();

  setUp((){
    methodChannel.setMockMethodCallHandler((call) async{
      if(call.method == 'getAutoStartConfiguration'){
        var result = Map();
        result["enabled"] = false;
        result['logLevel'] = true;
        result['crashReporting'] = true;
        result['webRequest'] = true;
        return result;
      }else if(call.method == 'reportCrash'){
        print('reportCrash errorValue:${call.arguments['errorValue']}, '
            'reason:${call.arguments['reason']}, '
            'stacktrace:${call.arguments['stacktrace']}, '
            'platform:${call.arguments['platform']}');
      //   reportCrash((String) call.argument("errorValue"), (String) call.argument("reason"),
      // (String) call.argument("stacktrace"), call.argument("platform"));
      }
    });
  });

  tearDown((){
    methodChannel.setMockMethodCallHandler(null);
  });

  test('start test', (){
    void startForTestCallBack(Widget widget){
      Logger().d('startCallback invoked');
    }
    TingyunFlutterImpl.private(methodChannel, startupFunction: startForTestCallBack).start(null);
  });
  
  test('test crash', (){
    Tingyun().start(null);
  });

  test('reportCrash test', (){
    void startForTestCallBack(Widget widget){
      Logger().d('startCallback invoked');
    }
    TingyunFlutterImpl tingyun = TingyunFlutterImpl.private(methodChannel, startupFunction: startForTestCallBack);
    tingyun.started = true;

    tingyun.reportError('test for reportCrash', '##1 do execute1;\n ##2 do execute2;');
  });



}

==> 2.1.0.tar.gz: test/agent/agent_impl_test.dart <==
import 'package:flutter/rendering.dart';
import 'package:flutter/services.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:tingyun_flutter_plugin/src/agent/agent_impl.dart';
import 'package:tingyun_flutter_plugin/src/agent/util/logger.dart';
import 'package:tingyun_flutter_plugin/tingyun_flutter_plugin.dart';

import '../dart_language_test.dart';

void main(){

  const MethodChannel methodChannel = MethodChannel(TingyunFlutterImpl.methodChannelName);
  TestWidgetsFlutterBinding.ensureInitialized();

  setUp((){
    methodChannel.setMockMethodCallHandler((call) async{
      if(call.method == 'getAutoStartConfiguration'){
        var result = Map();
        result["enabled"] = false;
        result['logLevel'] = true;
        result['crashReporting'] = true;
        result['webRequest'] = true;
        return result;
      }else if(call.method == 'reportCrash'){
        print('reportCrash errorValue:${call.arguments['errorValue']}, '
            'reason:${call.arguments['reason']}, '
            'stacktrace:${call.arguments['stacktrace']}, '
            'platform:${call.arguments['platform']}');
      //   reportCrash((String) call.argument("errorValue"), (String) call.argument("reason"),
      // (String) call.argument("stacktrace"), call.argument("platform"));
      }
    });
  });

  tearDown((){
    methodChannel.setMockMethodCallHandler(null);
  });

  test('start test', (){
    // void startForTestCallBack(Widget widget){
    //   Logger().d('startCallback invoked');
    // }
    // TingyunFlutterImpl.private(methodChannel, startupFunction: startForTestCallBack).start(null);
  });
  
  test('test crash', (){
    // Tingyun().start(null);
  });

  test('reportCrash test', (){
    void startForTestCallBack(Widget widget){
      Logger().d('startCallback invoked');
    }
    TingyunFlutterImpl tingyun = TingyunFlutterImpl.private(methodChannel, startupFunction: startForTestCallBack);
    tingyun.started = true;

    tingyun.reportError('test for reportCrash', '##1 do execute1;\n ##2 do execute2;');
  });



}
